tofu.geom — tofu v1.1

### Navigation

- index
- modules |
- tofu v1.1 »
- Module code »

# Source code for tofu.geom

    # -*- coding: utf-8 -*-
    #! /usr/bin/python

    """
    Load all core packages and modules which are all machine-independent, diagnostic-independent and code-independent

    Created on Wed May 18 2016

    @version: 0.9
    @author: didiervezinet
    @author_email: didier.vezinet@gmail.com
    """

    from ._core import *
    from . import General_Geom_cy as _GG

    del _core, General_Geom_cy

    #__name__ = ""
    __version__ = "1.1"
    __author__ = "Didier Vezinet"
    __author_email__="didier.vezinet@gmail.com"
    __date__ = "$Tuesday 07 June 2016$"
    #__copyright__ = ""
    #__license__ = ""
    #__url__ = ""
    #__path__ =

    __all__ = ['Ves','LOS','GLOS','Lens','Apert','Detect','GDetect',
               'Calc_Resolution','Plot_Resolution']

### Navigation

- index
- modules |
- tofu v1.1 »
- Module code »